@@ -302,28 +302,53 @@ class Store(registering.Registry):
 
         return self.addNode(name=name)   
 
-    def expose(self):
+    def expose(self, values=False):
         """   """
         print "Store name = %s, stamp = %s" % (self.name, self.stamp)
         print "Nodes & Shares:"
-        Store.ShowNode(self.shares, indent = 0)
+        Store.ShowNode(self.shares, indent = 0, values=values)
 
 
     @staticmethod
-    def ShowNode(node, indent = 0):
+    def ShowNode(node, indent = 0, values=False):
         if isinstance(node, dict):
             for key, value in node.items():
                 for i in range(indent):
                     print "  ",
                 print ".%s " % key
-                Store.ShowNode(value, indent = indent + 1)
+                Store.ShowNode(value, indent = indent + 1, values=values)
         else:
             for i in range(indent):
                 print "  ",
-            for key in node.keys():
-                print "%s " % key,
+            if values:
+                for key, val in node.items():
+                    print "%s=%s " % (key, val) ,                
+            else:
+                for key in node.keys():
+                    print "%s " % key,
             print
 
+class Mark(object):
+    """ Supports the UpdateNeed, ChangeNeed and Marker Actor
+        UpdateNeed checks if associated share is update while in associated frame
+        ChangeNeed checks if associated share data is changed while in associated frame
+        
+        
+        stamp = last stamp of associated share
+        data = copy of data of associated share
+        
+    """
+    __slots__ = ('stamp', 'data',) 
+    
+    
+    def __init__(self, *pa, **kwa):
+        """ Initialize instance. """
+        super(Mark,self).__init__(*pa, **kwa)
+        
+        self.stamp = None
+        self.data = None
+    
+
 class Share(object):
     """Shared item in data store
 
@@ -421,6 +446,8 @@ class Share(object):
             self.changUnit(**unit)
         if owner is not None:
             self.owner = owner
+        
+        self.marks = odict() #odict of marks
 
 
     #make share look like a dictionary for .data record fields
